;; Generated package description from beframe.el  -*- no-byte-compile: t -*-
(define-package "beframe" "0.1.10" "Isolate buffers per frame" '((emacs "28.1")) :commit "aa3783c92dabfa74386aa0ceebf74b48862d7b81" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou General Issues" . "~protesilaos/general-issues@lists.sr.ht") :url "https://git.sr.ht/~protesilaos/beframe")
